@@ -325,9 +325,9 @@ void Plink::mergeBinaryData()
 	  MSNP << *ilocus << "\n";
 	}
       MSNP.close();
-      printLOG("\nFound " + int2str(misstrand.size()) + " SNPs that do not match in terms of strand\n");
-      printLOG("(nb. flipped A/T and C/G SNPs will of course go undetected here)\n");
-      printLOG("Writing identifiable strand problem SNPs to [ " + f + " ]\n");
+      printLOG("\nFound " + int2str(misstrand.size()) + " SNPs that do not match in terms of allele codes\n");
+      printLOG("Might include strand flips, although flipped A/T and C/G SNPs will be undetected)\n");
+      printLOG("Writing problem SNPs to [ " + f + " ]\n");
       error("Stopping due to mis-matching SNPs -- check +/- strand?");
     }
   
@@ -671,6 +671,23 @@ void Plink::mergeBinaryData()
   
    if (bfile_SNP_major)
      {
+       
+       // Person look-up table
+       vector<Individual*>::iterator person = sample2.begin();
+       vector<int> vindn;
+       while ( person != sample2.end() )
+	 {
+	   map<string,int>::iterator isample = 
+	     msample.find((*person)->fid+"_"+(*person)->iid);
+	   int indn;
+	   if ( isample != msample.end() ) 
+	     indn = isample->second;
+	   else
+	     error("Internal error in --bmerge... should not happen...\n");	   
+	   vindn.push_back(indn);
+	   ++person;
+	 }
+       
 
       CSNP * snp;
       
@@ -680,17 +697,28 @@ void Plink::mergeBinaryData()
       while (s<locus2.size()) // for all SNPs in second file
 	{
 	  
-	  // Look up SNP
-	  //	  map<string,int>::iterator ilocus = mlocus.find(locus2[ s ]->name);
-	  //	  int l2 = ilocus->second;
+	  // Look up SNP information
 	  
+// 	  map<string,int>::iterator ilocus = mlocus.find(locus2[ s ]->name);
+// 	  int l2 = ilocus->second;
+	  
+	  int k0 = (int)ordered[s].freq;
+	  ilocus = mlocus.find(locus2[k0]->name);
+	  int k = ilocus->second;
+	  bool flipmode = flip_alleles.find( locus2[k0]->name ) != flip_alleles.end();
+	  string snp1 = locus2[ k0 ]->allele1;
+	  string snp2 = locus2[ k0 ]->allele2;
+	  bool existence = exists.find(locus2[k0]->name)->second;
+	  
+	  
+	  //////////////////////////////////////
 	  // Inner loop for individuals
 	  
-	  vector<Individual*>::iterator person = sample2.begin();
+	  vector<int>::iterator indn = vindn.begin();
 	  
-	  while ( person != sample2.end() )
+	  while ( indn != vindn.end() )
 	    {
-	      	      
+	      
 	      char ch[1];
 	      BIT.read(ch,1);
 	      
@@ -701,63 +729,42 @@ void Plink::mergeBinaryData()
 	      
 	      if (!BIT) 
 		error("Problem with the BED file...has the FAM file been changed?\n");
-	      
-	      
-	      while (c<7 && person != sample2.end() ) 
+	      	      
+	      while (c<7 && indn != vindn.end() ) 
 		{
 		  
-		  // Look up individual
-		  map<string,int>::iterator isample = 
-		    msample.find((*person)->fid+"_"+(*person)->iid);
-
-        	  int indn;
-		  if ( isample != msample.end() ) 
-		    {
-		      indn = isample->second;
-		    }
-         	  else
-		    error("Internal error in --bmerge... should not happen...\n");
-		  
-		  int k0 = (int)ordered[s].freq;
-		  ilocus = mlocus.find(locus2[k0]->name);
-		  int k = ilocus->second;
-		  
 		  bool s1 = b[c++];
 		  bool s2 = b[c++];
 		  
-		  if ( flip_alleles.find( locus2[k0]->name ) != flip_alleles.end() )
+		  if ( flipmode && s1 == s2 )
 		    {
-		      if ( s1 == s2 )
-			{
-			  s1 = !s1;
-			  s2 = !s2;
-			}
+		      s1 = !s1;
+		      s2 = !s2;
 		    }
-
-		  string one = locus2[ k0 ]->allele1;
-		  string two = locus2[ k0 ]->allele2;
 		  
-		  if (s1 && s2) one=two=locus2[ k0 ]->allele2;
-		  else if ( (!s1) && (!s2) ) one=two=locus2[ k0 ]->allele1;
+		  string one = snp1;
+		  string two = snp2;
+		  if (s1 && s2) one=snp2;
+		  else if ( (!s1) && (!s2) ) two=snp1;
 		  else if ( s1 && !s2 ) one=two=par::missing_genotype;
-		  		  
+		  
 		  bool already_in = false;
-		  if ( indn < original_sample_size ) already_in = true;
-		  else already_in = existing_person_list[indn - original_sample_size];
+		  if ( *indn < original_sample_size ) already_in = true;
+		  else already_in = existing_person_list[*indn - original_sample_size];
 
-                  bool e = reconcileMerge( indn, k , 
+                  bool e = reconcileMerge( *indn, k , 
  					   one, two, 
 	 				   already_in,
-					   exists.find(locus2[k0]->name)->second,
+					   existence,
 					   MERD, misstrand_dummy);	
 		  
 		  if (e) fatal_error=true;
 
 		  // next person
-		  person++;		  
-		  indn++;
+		  indn++;		  
+		  
 		}
-
+	      
 	    }
 	  
 	  
