@@ -573,14 +573,14 @@ void CCA_logit(bool perm,
 
 	    ////////////////////////////////////////////////////////
 	    // Step 2. Calculate the p x p matrix M1 = inv(sqrt(sig11)) %*% sig12 %*% inv(sig22) %*% sig21 %*% inv(sqrt(sig11))
-	      
+	    bool flag = true;
 	    I11 = msqrt(I11);
-	    I11 = svd_inverse(I11);
-       	    I22 = svd_inverse(I22);
+	    I11 = svd_inverse(I11,flag);
+       	    I22 = svd_inverse(I22,flag);
 
 	    I22b = msqrt(I22b);// For Step 4b
-	    I22b = svd_inverse(I22b);
-	    I11b = svd_inverse(I11b);
+	    I22b = svd_inverse(I22b,flag);
+	    I11b = svd_inverse(I11b,flag);
       
 	    matrix_t tmp;
 	    matrix_t M1;
@@ -1113,14 +1113,16 @@ void CCA_caseonly(bool perm,
 
 	    ////////////////////////////////////////////////////////
 	    // Step 2. Calculate the p x p matrix M1 = inv(sqrt(sig11)) %*% sig12 %*% inv(sig22) %*% sig21 %*% inv(sqrt(sig11))
-	          
+
+	    bool flag = true;
+
 	    I11 = msqrt(I11);
-	    I11 = svd_inverse(I11);
-	    I22 = svd_inverse(I22);
+	    I11 = svd_inverse(I11,flag);
+	    I22 = svd_inverse(I22,flag);
 
 	    I22b = msqrt(I22b);// For Step 4b
-	    I22b = svd_inverse(I22b);
-	    I11b = svd_inverse(I11b);
+	    I22b = svd_inverse(I22b,flag);
+	    I11b = svd_inverse(I11b,flag);
       
 	    matrix_t tmp;
 	    matrix_t M1;
