@@ -1564,10 +1564,12 @@ void IDHelper::idReplace()
 	       + fname + " from [ " + tok[0] + " ]\n");
   PP->printLOG("Writing new file to [ " + par::output_file_name + ".rep ]\n");
   
-  bool skipMode = par::idhelp_replace_options.isSet("skip");
-  bool missMode = par::idhelp_replace_options.isSet("miss");
-  bool warnMode = par::idhelp_replace_options.isSet("warn");
-  bool listMode = par::idhelp_replace_options.isSet("list");
+  OptionSet * id_opt = par::opt.getOptions("IDHELP");
+
+  bool skipMode = id_opt->isSet("skip");
+  bool missMode = id_opt->isSet("miss");
+  bool warnMode = id_opt->isSet("warn");
+  bool listMode = id_opt->isSet("list");
   
   int c = 0;
   
@@ -1604,7 +1606,7 @@ void IDHelper::idReplace()
   
   // Do we have a header row?
   bool header = false;
-  if ( par::idhelp_replace_options.isSet("header") )
+  if ( id_opt->isSet("header") )
     header = true;
   
       
@@ -1613,8 +1615,8 @@ void IDHelper::idReplace()
     {
       string field_str;
       
-      if ( par::idhelp_replace_options.isSet("field") )
-	field_str = par::idhelp_replace_options.getValue("field");
+      if ( id_opt->isSet("field") )
+	field_str = id_opt->getValue("field");
       else
 	error("Need to specify field={N,N} if no header");
       
@@ -2145,11 +2147,12 @@ void IDHelper::idMatch()
   // each unique individual
   
   // Only output complete rows?
+  OptionSet * id_opt = par::opt.getOptions("IDHELP");
 
   bool complete = false;
-  if ( par::idhelp_match_options.isSet("complete") ) 
+  if ( id_opt->isSet("complete") ) 
     complete = true;
-  if ( par::idhelp_match_options.isSet("noheader") )
+  if ( id_opt->isSet("noheader") )
     atleastOneHeader = false;
   
   PP->printLOG("Writing output file to [ " + par::output_file_name + ".matched ]\n");
