@@ -981,6 +981,7 @@ void Plink::display_recoded_PEDFILE()
   
   PED.close();
   
+  
   // And we also need a new map file
   
   if (par::recode_HV)
@@ -1075,6 +1076,256 @@ void Plink::display_recoded_PEDFILE()
 }
 
 
+void Plink::display_recoded_MUTLIST()
+{
+  
+  string f = par::output_file_name + ".rlist";
+  
+  printLOG("Writing rare-list file to [ " + f + " ] \n");
+
+  ofstream PED(f.c_str(), ios::out);
+  
+  for (int l=0;l<nl_all;l++)
+    {
+ 
+      // Hets, homs, missing
+      
+      set<int> het;
+      set<int> hom;
+      set<int> missing;
+      
+      for (int i=0;i<n;i++)
+	{
+	  Individual * person = sample[i];
+	  
+	  // A non-reference genotype?
+	  
+	  bool a1 = par::SNP_major ? SNP[l]->one[i] : person->one[l];
+	  bool a2 = par::SNP_major ? SNP[l]->two[i] : person->two[l];
+	  
+	  if ( (!a1) && (!a2) )
+	    hom.insert(i);
+	  else if ( (!a1) && a2 )
+	    het.insert(i);
+	  else if ( a1 && ! a2 ) 
+	    missing.insert(i);
+	}
+      
+
+      // Hets
+      if ( het.size() > 0 )
+	{
+	  PED << locus[l]->name << par::recode_delimit 
+	      << "HET" << par::recode_delimit 
+	      << locus[l]->allele1 << par::recode_indelimit 
+	      << locus[l]->allele2;
+	  set<int>::iterator j = het.begin();
+	  while ( j != het.end() )
+	    {
+	      PED << par::recode_delimit << sample[*j]->fid 
+		  << par::recode_delimit << sample[*j]->iid;
+	      ++j;
+	    }
+	  PED << "\n";
+	}
+
+      // Homozygotes
+      if ( hom.size() > 0 )
+	{
+	  PED << locus[l]->name << par::recode_delimit 
+	      << "HOM" << par::recode_delimit 
+	      << locus[l]->allele1 << par::recode_indelimit 
+	      << locus[l]->allele1;
+	  set<int>::iterator j = hom.begin();
+	  while ( j != hom.end() )
+	    {
+	      PED << par::recode_delimit << sample[*j]->fid 
+		  << par::recode_delimit << sample[*j]->iid;
+	      ++j;
+	    }
+	  PED << "\n";
+	}
+
+      // Missing genotypes
+      if ( missing.size() > 0 )
+	{
+	  PED << locus[l]->name << par::recode_delimit 
+	      << "NIL" << par::recode_delimit 
+	      << par::missing_genotype << par::recode_indelimit 
+	      << par::missing_genotype;
+	  set<int>::iterator j = missing.begin();
+	  while ( j != missing.end() )
+	    {
+	      PED << par::recode_delimit << sample[*j]->fid 
+		  << par::recode_delimit << sample[*j]->iid;
+	      ++j;
+	    }
+	  PED << "\n";
+	}
+
+
+      }
+  
+  PED.close();
+    
+  // And a corresponding MAP file
+
+  f = par::output_file_name + ".map";
+  printLOG( "Writing new map file to [ " + f + " ] \n");  
+  ofstream MAP(f.c_str(), ios::out);
+  for (int l=0;l<nl_all;l++)
+    {
+      MAP << locus[l]->chr << "\t"
+	  << locus[l]->name << "\t"
+	  << locus[l]->pos << "\t"
+	  << locus[l]->bp << "\n";
+    }
+
+  MAP.close();
+
+
+  printLOG( "Writing pedigree information to [ " 
+	    + par::output_file_name + ".fam ] \n");
+  ofstream FAM((par::output_file_name+".fam").c_str(), ios::out);
+
+  for (int i=0;i<n;i++)
+    {
+      Individual * person = sample[i];
+      FAM << person->fid << " "
+	  << person->iid << " "
+	  << person->pat << " "
+	  << person->mat << " "
+	  << person->sexcode << " ";
+      
+      if ( person->missing )
+	FAM << par::out_missing_phenotype << "\n";
+      else
+	{
+	  if (par::bt)
+	    FAM << (int)person->phenotype << "\n";
+	  else
+	    FAM << person->phenotype << "\n";
+	}
+    }
+  FAM.clear();
+  FAM.close();
+
+}
+
+void Plink::display_recoded_LONG()
+{
+  
+  string f = par::output_file_name + ".lgen";
+  
+  printLOG("Writing recoded LGEN file to [ " + f + " ] \n");
+
+  ofstream PED(f.c_str(), ios::out);
+
+  string missingCode = par::out_missing_phenotype;
+
+  for (int l=0;l<nl_all;l++)
+    for (int i=0;i<n;i++)
+      {
+
+	Individual * person = sample[i];	
+
+	if ( par::recode_long_ref )
+	  {
+	    // Skip reference homozygotes?
+	    bool a1 = par::SNP_major ? SNP[l]->one[i] : person->one[l];
+	    bool a2 = par::SNP_major ? SNP[l]->two[i] : person->two[l];
+	    if ( a1 && a2 ) 
+	      continue;
+	  }
+		
+	PED << person->fid << par::recode_delimit
+	    << person->iid << par::recode_delimit
+	    << locus[l]->name << par::recode_delimit
+	    << genotypeToFile( *this , i, l ) << "\n";
+
+      }
+  
+  PED.close();
+    
+  // And a corresponding MAP file
+
+  f = par::output_file_name + ".map";
+  printLOG( "Writing new map file to [ " + f + " ] \n");  
+  ofstream MAP(f.c_str(), ios::out);
+  for (int l=0;l<nl_all;l++)
+    {
+      MAP << locus[l]->chr << "\t"
+	  << locus[l]->name << "\t"
+	  << locus[l]->pos << "\t"
+	  << locus[l]->bp << "\n";
+    }
+
+  MAP.close();
+
+
+  //////////////////////////////////////////
+  // And a corresponding reference file?
+ 
+  if ( par::recode_long_ref )
+    {
+      f = par::output_file_name + ".ref";
+      printLOG( "Writing new reference file to [ " + f + " ] \n");  
+      ofstream MAP(f.c_str(), ios::out);
+      for (int l=0;l<nl_all;l++)
+	{
+
+	  if ( locus[l]->allele1 == par::missing_genotype && 
+	       locus[l]->allele2 == par::missing_genotype )
+	    continue;
+
+	  MAP << locus[l]->name;
+
+	  if ( locus[l]->allele2 != par::missing_genotype )
+	    MAP << " " << locus[l]->allele2;
+
+	  if ( locus[l]->allele1 != par::missing_genotype )
+	    MAP << " " << locus[l]->allele1;
+	  MAP << "\n";
+
+	}      
+      MAP.close();
+    }
+  
+
+  //////////////////////////////////////////
+  // And a corresponding FAM file?
+ 
+  printLOG( "Writing pedigree information to [ " 
+	    + par::output_file_name + ".fam ] \n");
+  ofstream FAM((par::output_file_name+".fam").c_str(), ios::out);
+
+  for (int i=0;i<n;i++)
+    {
+      Individual * person = sample[i];
+      FAM << person->fid << " "
+	  << person->iid << " "
+	  << person->pat << " "
+	  << person->mat << " "
+	  << person->sexcode << " ";
+      
+      if ( person->missing )
+	FAM << par::out_missing_phenotype << "\n";
+      else
+	{
+	  if (par::bt)
+	    FAM << (int)person->phenotype << "\n";
+	  else
+	    FAM << person->phenotype << "\n";
+	}
+    }
+  FAM.clear();
+  FAM.close();
+  
+}
+
+
+
+
 void Plink::output_fastphase_format()
 {
 
@@ -1304,6 +1555,8 @@ void Plink::display_recoded_PEDFILE_transpose()
   ofstream PED(f.c_str(), ios::out);
   PED.clear();
 
+  //  par::recode_indelimit = "";
+
   for (int l=0;l<nl_all;l++)
     {
       PED << locus[l]->chr << par::recode_delimit
@@ -1319,7 +1572,7 @@ void Plink::display_recoded_PEDFILE_transpose()
   
   PED.close();
   
-
+  
   // And we also need a new family info file
 
   f = par::output_file_name + ".tfam";
