@@ -151,7 +151,7 @@ void Set::pruneMC(Plink & P, bool disp,double VIF_threshold)
 
       // Perform VIF pruning, setting filters (S.cur[][])
 
-      vector<bool> p = vif_prune(var,VIF_threshold);
+      vector<bool> p = vif_prune(var,VIF_threshold,nSNP);
 
       for (int i=0; i<nss; i++)
 	if (!p[i]) cur[s][i]=false;
@@ -734,8 +734,9 @@ vector_t Set::profileTestScore()
 
       ////////////////////////////////
       // Calculate actual profile
-
-      PP->calculateProfile(scores, allele1, profile, count, acount);
+      
+      matrix_t dummy;
+      PP->calculateProfile(scores, allele1, profile, dummy , count, acount);
       
 
       ///////////////////////////////////////////////
@@ -973,7 +974,7 @@ vector_t Set::fitLDSetTest( vector_t & singleSNP, bool save )
 	  
 	  for (int k=0; k<selected.size(); k++)
 	    {	      
-	      set<int>::iterator d = ls.find(k);
+	      set<int>::iterator d = ls.find(selected[k]);
 	      if ( d != ls.end() )
 		{
 		  hasProxy = true;
